API
===

Module Interface
----------------
.. automodule:: pyaardvark
   :members: api_version, find_devices, open

Constants
---------
.. automodule:: pyaardvark.constants

Aardvark Object
---------------

.. autoclass:: pyaardvark.Aardvark
   :members:
